
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.1.38'
version = '1.1.38'
full_version = '1.1.38'
git_revision = '1545d9a0f9157f20d95589008133810fe37b9660'
release = True

if not release:
    version = full_version
    short_version += ".dev"
